LiteSVM

Struct LiteSVM 

pub struct LiteSVM { /* private fields */ }

Implementations

Source

impl LiteSVM

pub fn new() -> Self

Creates the basic test environment.

pub fn with_compute_budget(self, compute_budget: ComputeBudget) -> Self

Sets the compute budget.

pub fn with_sigverify(self, sigverify: bool) -> Self

Enables or disables sigverify.

pub fn with_blockhash_check(self, check: bool) -> Self

Enables or disables the blockhash check.

pub fn with_sysvars(self) -> Self

Includes the default sysvars.

pub fn with_feature_set(self, feature_set: FeatureSet) -> Self

Set the FeatureSet used by the VM instance.

pub fn with_builtins(self) -> Self

Changes the default builtins.

pub fn with_lamports(self, lamports: u64) -> Self

Changes the initial lamports in LiteSVM’s airdrop account.

pub fn with_default_programs(self) -> Self

Includes the standard SPL programs.

pub fn with_transaction_history(self, capacity: usize) -> Self

Changes the capacity of the transaction history. Set this to 0 to disable transaction history and allow duplicate transactions.

pub fn with_log_bytes_limit(self, limit: Option<usize>) -> Self

pub fn minimum_balance_for_rent_exemption(&self, data_len: usize) -> u64

Returns minimum balance required to make an account with specified data length rent exempt.

pub fn get_account(&self, address: &Address) -> Option<Account>

Returns all information associated with the account of the provided pubkey.

pub fn set_account( &mut self, address: Address, data: Account, ) -> Result<(), LiteSVMError>

Sets all information associated with the account of the provided pubkey.

pub fn accounts_db(&self) -> &AccountsDb

⚠️ ADVANCED USE ONLY ⚠️

Returns a reference to the internal accounts database.

This provides read-only access to the accounts database for advanced inspection. Use get_account for normal account retrieval.

Examples
use litesvm::LiteSVM;

let svm = LiteSVM::new();

// Read-only access to accounts database
let accounts_db = svm.accounts_db();
// ... inspect internal state if needed
pub fn get_balance(&self, address: &Address) -> Option<u64>

Gets the balance of the provided account pubkey.

pub fn latest_blockhash(&self) -> Hash

Gets the latest blockhash.

pub fn set_sysvar<T>(&mut self, sysvar: &T)

Sets the sysvar to the test environment.

pub fn get_sysvar<T>(&self) -> T

Gets a sysvar from the test environment.

pub fn get_transaction( &self, signature: &Signature, ) -> Option<&TransactionResult>

Gets a transaction from the transaction history.

pub fn airdrop_pubkey(&self) -> Address

Returns the pubkey of the internal airdrop account.

pub fn airdrop(&mut self, address: &Address, lamports: u64) -> TransactionResult

Airdrops the account with the lamports specified.

pub fn add_builtin( &mut self, program_id: Address, entrypoint: BuiltinFunctionWithContext, )

Adds a builtin program to the test environment.

pub fn add_program_from_file( &mut self, program_id: impl Into<Address>, path: impl AsRef<Path>, ) -> Result<(), LiteSVMError>

Adds an SBF program to the test environment from the file specified.

pub fn add_program( &mut self, program_id: impl Into<Address>, program_bytes: &[u8], ) -> Result<(), LiteSVMError>

Adds am SBF program to the test environment.

pub fn send_transaction( &mut self, tx: impl Into<VersionedTransaction>, ) -> TransactionResult

Submits a signed transaction.

pub fn simulate_transaction( &self, tx: impl Into<VersionedTransaction>, ) -> Result<SimulatedTransactionInfo, FailedTransactionMetadata>

Simulates a transaction.

pub fn expire_blockhash(&mut self)

Expires the current blockhash.

pub fn warp_to_slot(&mut self, slot: u64)

Warps the clock to the specified slot.

pub fn get_compute_budget(&self) -> Option<ComputeBudget>

Gets the current compute budget.

pub fn get_sigverify(&self) -> bool